aboutsummaryrefslogtreecommitdiffstats
path: root/build/update.sh
diff options
context:
space:
mode:
authorJoas Schilling <coding@schilljs.com>2024-08-14 13:53:22 +0200
committerJoas Schilling <coding@schilljs.com>2024-08-14 13:53:22 +0200
commit5a554100830df287f96568328d00ad7544ce8480 (patch)
treeb59cb0df649aa88a3e26bcc04724ec0bbcabe76d /build/update.sh
parent2659b2113d9d4c3c34609ecf99591f2f9f66bc44 (diff)
downloadnextcloud-server-5a554100830df287f96568328d00ad7544ce8480.tar.gz
nextcloud-server-5a554100830df287f96568328d00ad7544ce8480.zip
chore(branchoff): Test against stable30 branches
Signed-off-by: Joas Schilling <coding@schilljs.com>
Diffstat (limited to 'build/update.sh')
-rwxr-xr-xbuild/update.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/build/update.sh b/build/update.sh
index 4f20535d917..6a45166bea7 100755
--- a/build/update.sh
+++ b/build/update.sh
@@ -3,17 +3,17 @@
# SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
# SPDX-License-Identifier: AGPL-3.0-or-later
#
# Update Nextcloud server and apps from latest git master
# For local development environment
# Use from Nextcloud server folder with `./build/update.sh`
# Update server
printf "\n\033[1m${PWD##*/}\033[0m\n"
-git checkout master
+git checkout stable30
git pull --quiet -p
git --no-pager log -3 --pretty=format:"%h %Cblue%ar%x09%an %Creset%s"
printf "\n"
-git branch --merged master | grep -v "master$" | xargs git branch -d
+git branch --merged stable30 | grep -v "stable30$" | xargs git branch -d
git submodule update --init
# Update apps
@@ -3,17 +3,17 @@
# SPDX-License-Identifier: AGPL-3.0-or-later
#
-# Update Nextcloud server and apps from latest git master
+# Update Nextcloud server and apps from latest git stable30
# For local development environment
# Use from Nextcloud server folder with `./build/update.sh`